@@ -1,11 +1,13 @@
+
+
 """Version information for GravixLayer SDK"""
 
-__version__ = "0.0.17"
+__version__ = "0.0.47"
 __version_info__ = tuple(int(x) for x in __version__.split('.'))
 
 # Version history
 VERSION_HISTORY = {
-    "0.0.2": "Initial release with OpenAI compatibility",
+    "0.0.2": "Initial release ",
     # Add future versions here
 }
 
